#ifndef KS_SETTINGS_H
#define KS_SETTINGS_H

#include "common/settings.h"


class KSGameConfig : public GameConfig
{
    TQ_OBJECT
  
 public:
    KSGameConfig();
};

#endif
